import datetime
import pathlib
import subprocess
import sys

import click
import semver


def find_root() -> pathlib.Path:
    path = pathlib.Path.cwd()
    while path != path.parent:
        if (path / ".git").is_dir():
            return path
        path = path.parent
    raise click.ClickException(
        f"The current path {pathlib.Path.cwd()} is not a part of Git repo"
    )


@click.command()
def main() -> None:
    setup_py = find_root() / "setup.py"
    if not setup_py.exists():
        raise click.ClickException(f"{setup_py} doesn't exist")
    if not setup_py.is_file():
        raise click.ClickException(f"{setup_py} is not a file")
    if "use_scm_version" not in setup_py.read_text():
        raise click.ClickException(f"{setup_py} doesn't contain use_scm_version clause")

    out = subprocess.run(["git", "tag", "-l"], capture_output=True, text=True)
    if out.returncode:
        click.echo(out.stdout, nl=False)
        click.echo(out.stderr, nl=False, err=True)
        sys.exit(out.returncode)
    today = datetime.date.today()
    current = semver.Version(today.year % 100, today.month)
    versions = sorted(
        semver.Version.parse(line.strip()) for line in out.stdout.splitlines()
    )
    versions = [
        v for v in versions if v.major == current.major and v.minor == current.minor
    ]

    if not versions:
        version = current
    else:
        version = versions[-1].next_patch

    click.echo(f"Tag version v{version}:")
    click.secho(f"git tag -a v{version} -m 'Release {version}'", bold=True)
    subprocess.run(
        ["git", "tag", "-a", f"v{version}", "-m", f"Release {version}"],
        check=True,
    )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['neuro_bump_version']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.1,<8.1.0', 'poetry-semver>=0.1.0,<0.2.0']

entry_points = \
{'console_scripts': ['neuro-bump-version = neuro_bump_version.main:main']}

setup_kwargs = {
    'name': 'neuro-bump-version',
    'version': '21.9',
    'description': 'Bump version for Neu.ro projects',
    'long_description': '# neuro-bump-version\nBump neu-ro tag to the next version\n',
    'author': 'Andrew Svetlov',
    'author_email': 'andrew.svetlov@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/neuro-inc/neuro-bump-version',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)
